errunchecked

package
v0.0.0-...-9e0ab32 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 18, 2026 License: MIT Imports: 10 Imported by: 0

Documentation

Overview

Package errunchecked provides a Go analyzer that detects when errutil.With or errutil.Wrap is called directly on a function call result without first checking for nil.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Analyzer

func Analyzer() *analysis.Analyzer

Types

This section is empty.

Directories

Path Synopsis
cmd
errunchecked command

Jump to